==> aws-java-sdk-simpleworkflow-1.11.46-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/StartLambdaFunctionFailedEventAttributesJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * StartLambdaFunctionFailedEventAttributesMarshaller
 */
public class StartLambdaFunctionFailedEventAttributesJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(StartLambdaFunctionFailedEventAttributes startLambdaFunctionFailedEventAttributes, StructuredJsonGenerator jsonGenerator) {

        if (startLambdaFunctionFailedEventAttributes == null) {
            throw new AmazonClientException("Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (startLambdaFunctionFailedEventAttributes.getScheduledEventId() != null) {
                jsonGenerator.writeFieldName("scheduledEventId").writeValue(startLambdaFunctionFailedEventAttributes.getScheduledEventId());
            }
            if (startLambdaFunctionFailedEventAttributes.getCause() != null) {
                jsonGenerator.writeFieldName("cause").writeValue(startLambdaFunctionFailedEventAttributes.getCause());
            }
            if (startLambdaFunctionFailedEventAttributes.getMessage() != null) {
                jsonGenerator.writeFieldName("message").writeValue(startLambdaFunctionFailedEventAttributes.getMessage());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static StartLambdaFunctionFailedEventAttributesJsonMarshaller instance;

    public static StartLambdaFunctionFailedEventAttributesJsonMarshaller getInstance() {
        if (instance == null)
            instance = new StartLambdaFunctionFailedEventAttributesJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-simpleworkflow-1.11.52-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/StartLambdaFunctionFailedEventAttributesJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.SdkClientException;
import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * StartLambdaFunctionFailedEventAttributesMarshaller
 */
public class StartLambdaFunctionFailedEventAttributesJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(StartLambdaFunctionFailedEventAttributes startLambdaFunctionFailedEventAttributes, StructuredJsonGenerator jsonGenerator) {

        if (startLambdaFunctionFailedEventAttributes == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (startLambdaFunctionFailedEventAttributes.getScheduledEventId() != null) {
                jsonGenerator.writeFieldName("scheduledEventId").writeValue(startLambdaFunctionFailedEventAttributes.getScheduledEventId());
            }
            if (startLambdaFunctionFailedEventAttributes.getCause() != null) {
                jsonGenerator.writeFieldName("cause").writeValue(startLambdaFunctionFailedEventAttributes.getCause());
            }
            if (startLambdaFunctionFailedEventAttributes.getMessage() != null) {
                jsonGenerator.writeFieldName("message").writeValue(startLambdaFunctionFailedEventAttributes.getMessage());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static StartLambdaFunctionFailedEventAttributesJsonMarshaller instance;

    public static StartLambdaFunctionFailedEventAttributesJsonMarshaller getInstance() {
        if (instance == null)
            instance = new StartLambdaFunctionFailedEventAttributesJsonMarshaller();
        return instance;
    }

}
